@@ -73,6 +73,26 @@ cmp (){
     fi
 }
 
+summary2oneline() {
+    # $1 -- no-empty string for no sorting
+    awk -v first=1 '
+	NF == 0 {
+	    printf "\n"
+	    first=1
+	    next
+	}
+	{
+	    if (!first) printf ";"
+	    printf "%s", $0
+	    first=0
+	}' |
+	if test -z "$1"; then
+	    sort
+	else
+	    cat
+	fi
+}
+
 # real tests
 tests='
 pkg_cksum2summary
