@@ -149,6 +149,10 @@ PKGNAME=emacs-21.4anb19
 
 PKGNAME=emacs-22.3nb10
 
+PKGNAME=py27-dbus-0.83.1nb3
+
+PKGNAME=dbus-1.2.4.6nb4
+
 '
 
 pkg_uniq_summary -Fb src_summary9.txt |
@@ -176,6 +180,10 @@ PKGNAME=dictem-1.0.2nb1
 
 PKGNAME=emacs-23.2nb2
 
+PKGNAME=py27-dbus-0.83.1nb3
+
+PKGNAME=dbus-1.2.4.6nb4
+
 '
 
 pkg_uniq_summary -Fpa src_summary7.txt |
